@@ -19,7 +19,7 @@
 ** Those portions of the Subject Software created by Silicon Graphics, Inc.
 ** are Copyright (c) 1991-9 Silicon Graphics, Inc. All Rights Reserved.
 **
-** $Header: //sw/OEM/nvr40_linux2/drivers/OpenGL/win/glx/include/glxtokens.h#1 $
+** $Header: //sw/OEM/nvr40_linux_4498/drivers/OpenGL/win/glx/include/glxtokens.h#1 $
 */
 
 #ifdef __cplusplus
@@ -28,6 +28,7 @@ extern "C" {
 
 #define GLX_VERSION_1_1         1
 #define GLX_VERSION_1_2         1
+#define GLX_VERSION_1_3         1
 
 /* GLX Extensions */
 #define GLX_EXT_import_context  1
@@ -36,6 +37,7 @@ extern "C" {
 #define GLX_SGIX_fbconfig       1
 #define GLX_SGIX_pbuffer        1
 #define GLX_NV_float_buffer     1
+#define GLX_ARB_get_proc_address 1
 
 /*
  * Names for attributes to glXGetConfig.
